Name:          rome
Version:       1.6.0
Release:       %mkrel 1
Summary:       RSS and Atom Utilities
License:       ASL 2.0
Group:         Development/Java
URL:           http://rometools.github.io/rome/
# Original source archive 73,8 MB
# sh rome-create-tarball.sh < VERSION >
# Repackaged source archive 575 KB
Source0:       %{name}-%{version}.tar.xz

Source1:       %{name}-create-tarball.sh
# https://github.com/rometools/rome/issues/288
Patch0:        https://github.com/rometools/rome/commit/a090ed9b242ef6dfe178177bd57318443407d1d2.patch
Patch1:        https://github.com/rometools/rome/commit/15a5f15ed055c2f373141d54a8b33264fe82ab14.patch

BuildRequires: maven-local
BuildRequires: mvn(ch.qos.logback:logback-classic)
BuildRequires: mvn(commons-beanutils:commons-beanutils)
BuildRequires: mvn(commons-httpclient:commons-httpclient)
BuildRequires: mvn(javax.persistence:persistence-api)
BuildRequires: mvn(javax.servlet:javax.servlet-api)
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(net.oauth.core:oauth)
BuildRequires: mvn(org.apache.commons:commons-lang3)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.apache.xmlrpc:xmlrpc-client)
BuildRequires: mvn(org.hamcrest:hamcrest-library)
BuildRequires: mvn(org.jdom:jdom2)
BuildRequires: mvn(org.slf4j:slf4j-api)
BuildRequires: mvn(org.sonatype.oss:oss-parent:pom:)
BuildRequires: mvn(xmlunit:xmlunit)

BuildArch:     noarch

%description
ROME is an set of open source Java tools for parsing, generating and
publishing RSS and Atom feeds.

%package certiorem
Summary:       A PubSubHubub implementation for Java based on ROME

%description certiorem
PubSubHubub protocol implementation based on ROME.

%package fetcher
Summary:       Retrieves RSS feeds via HTTP conditional gets using ROME

%description fetcher
ROME Fetcher is a caching feed fetcher that supports retrieval of
feeds via HTTP conditional GET. Supports ETags, GZip compression,
and RFC3229 Delta encoding.

%package modules
Summary:       Plugin collection for the ROME RSS and Atom Utilities
# LGPL:
# rome-modules/src/main/java/com/rometools/modules/base/Course.java
# rome-modules/src/main/java/com/rometools/modules/base/CustomTagImpl.java
# rome-modules/src/main/java/com/rometools/modules/content/ContentItem.java
# rome-modules/src/main/java/com/rometools/modules/itunes/types/Duration.java
# rome-modules/src/main/java/com/rometools/modules/photocast/PhotocastModule.java
# rome-modules/src/main/java/com/rometools/modules/slash/Slash.java
# rome-modules/src/main/java/com/rometools/modules/yahooweather/YWeatherEntryModule.java
License:       ASL 2.0 and LGPLv2

%description modules
This module contains extensions that enable ROME to
handle several feed extensions like MediaRSS,
GeoRSS and others.

%package opml
Summary:       Support for OPML 1 and OPML 2 in ROME

%description opml
This module contains Outline Processor Markup Language parser and tools.

%package parent
Summary:       Parent for all ROME projects

%description parent
Parent POM for all ROME projects.

%package propono
Summary:       ROME Propono

%description propono
The ROME Propono sub-project is a Java class library that
supports publishing protocols, specifically the Atom Publishing Protocol
and the legacy MetaWeblog API. Propono includes an Atom client library,
Atom server framework and a Blog client that supports both Atom protocol
and the MetaWeblog API. 

%package utils
Summary:       Utility classes for ROME projects

%description utils
This modules provides utility classes for all ROME projects.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

# Unneeded tasks
%pom_remove_plugin -r :maven-scm-publish-plugin

%pom_xpath_remove -r "pom:Embed-Dependency" %{name} %{name}-modules
%pom_xpath_remove "pom:Embed-Transitive" %{name}-modules

%pom_change_dep -r com.rometools: ::'${project.version}'

# Force servlet 3.1
%pom_change_dep -r :servlet-api javax.servlet:javax.servlet-api:3.1.0
sed -i "s|String, Object|String, String[]|" \
 %{name}-propono/src/main/java/com/rometools/propono/atom/server/AtomRequestImpl.java \
 %{name}-propono/src/main/java/com/rometools/propono/atom/server/AtomRequest.java

# com.google.inject.extensions:guice-servlet
%pom_disable_module rome-certiorem-webapp
# No test deps (contains only tests)
# org.ops4j.pax.exam:pax-exam-container-native:4.8.0
# org.ops4j.pax.exam:pax-exam-junit4:4.8.0
# org.ops4j.pax.exam:pax-exam-link-mvn:4.8.0
# org.ops4j.pax.url:pax-url-wrap:2.4.5
%pom_disable_module rome-osgi-test

# No test dep
# jetty:jetty:4.2.12
%pom_remove_dep -r jetty:jetty
rm %{name}-fetcher/src/test/java/com/rometools/fetcher/AbstractJettyTest.java \
 %{name}-fetcher/src/test/java/com/rometools/fetcher/impl/HttpClientFeedFetcherTest.java \
 %{name}-fetcher/src/test/java/com/rometools/fetcher/impl/HttpURLFeedFetcherTest.java \
 %{name}-propono/src/test/java/com/rometools/propono/atom/server/AtomClientServerTest.java \
 %{name}-propono/src/test/java/com/rometools/propono/atom/server/TestAtomHandlerImpl.java \
 %{name}-propono/src/test/java/com/rometools/propono/atom/server/TestAtomHandlerFactory.java

# @ random fails
rm %{name}-certiorem/src/test/java/com/rometools/certiorem/hub/DeltaSyndFeedInfoTest.java

# Convert from dos to unix line ending
for f in README.md \
  %{name}/README.md \
  %{name}-certiorem/README.md \
  %{name}-fetcher/README.md \
  %{name}-modules/README.md \
  %{name}-opml/README.md \
  %{name}-propono/README.md \
  %{name}-utils/README.md
 do
   sed -i.orig 's|\r||g' $f
   touch -r $f.orig $f
   rm $f.orig
done

%mvn_alias com.rometools:%{name} %{name}:%{name} net.java.dev.%{name}:%{name}

%build

%mvn_build -s 

%install
%mvn_install

%files -f .mfiles-%{name}
%doc %{name}/README.md
%license %{name}/LICENSE

%files certiorem -f .mfiles-%{name}-certiorem
%doc %{name}-certiorem/README.md
%license %{name}-certiorem/LICENSE

%files fetcher -f .mfiles-%{name}-fetcher
%doc %{name}-fetcher/README.md
%license %{name}-fetcher/LICENSE

%files modules -f .mfiles-%{name}-modules
%doc %{name}-modules/README.md
%license %{name}-modules/LICENSE

%files opml -f .mfiles-%{name}-opml
%doc %{name}-opml/README.md

%files parent -f .mfiles-%{name}-parent
%doc README.md
%license LICENSE

%files propono -f .mfiles-%{name}-propono
%doc %{name}-propono/README.md
%license %{name}-propono/LICENSE %{name}-propono/NOTICE

%files utils -f .mfiles-%{name}-utils
%doc %{name}-utils/README.md
%license %{name}-utils/LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE




%changelog
* Fri Apr 28 2017 neoclust <neoclust> 1.6.0-1.mga6
+ Revision: 1097881
- New version( sync with fedora ) needed by springframework
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 0.9-21.mga6
+ Revision: 978142
- First rebuild of the java stack
- sync package rome with fedora
- imported package rome

* Tue Feb 09 2016 umeabot <umeabot> 0.9-17.mga6
+ Revision: 952022
- Mageia 6 Mass Rebuild

* Tue Jan 13 2015 daviddavid <daviddavid> 0.9-16.mga5
+ Revision: 810477
- Sync with fc21
- fix Group
- update requirements

* Wed Oct 15 2014 umeabot <umeabot> 0.9-15.mga5
+ Revision: 745514
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9-14.mga5
+ Revision: 688692
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.9-13.mga4
+ Revision: 518066
- Mageia 4 Mass Rebuild

* Mon Jan 14 2013 umeabot <umeabot> 0.9-12.mga3
+ Revision: 380398
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + dmorgan <dmorgan>
    - Rebuilde against Java7

* Mon Sep 10 2012 dmorgan <dmorgan> 0.9-2.mga3
+ Revision: 291912
- Add maven pom support

* Sat Nov 05 2011 gil <gil> 0.9-1.mga2
+ Revision: 163034
- edit description
- edit maven2 poms
- imported package rome


* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.9-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jun 23 2015 Mat Booth <mat.booth@redhat.com> - 0.9-19
- Adopt xmvn

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun 9 2014 Alexander Kurtakov <akurtako@redhat.com> 0.9-17
- Fix FTBFS.

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-16
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Feb 21 2014 Alexander Kurtakov <akurtako@redhat.com> 0.9-15
- Require java-headless.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri May 25 2012 gil cattaneo <puntogil@libero.it> 0.9-11
- Added maven POM

* Tue Apr 17 2012 Alexander Kurtakov <akurtako@redhat.com> 0.9-10
- Adapt to current guidelines.

* Fri Apr 13 2012 Krzysztof Daniel <kdaniel@redhat.com> 0.9-9
- Use Java 7
- Use latest jdom

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb 15 2010 Alexander Kurtakov <akurtako@redhat.com> 0.9-6
- Fix build with latest jdom. (rhbz#565057)

* Mon Jan 11 2010 Andrew Overholt <overholt@redhat.com> 0.9-5
- Update URL in instructions for getting MANIFEST.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Mon Mar 30 2009 Andrew Overholt <overholt@redhat.com> 0.9-3
- Fix javadoc Group (rhbz#492761).

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Jul 25 2008 Andrew Overholt <overholt@redhat.com> 0.9-1
- Initial Fedora version
